@@ -23,9 +23,9 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once(dirname(__FILE__).'/savane_error.class');
+require_once(dirname (__FILE__) . '/savane_error.php');
 
-$PROJECT_OBJ = array();
+$PROJECT_OBJ = [];
 
 function project_get_object ($group_id)
 {
@@ -41,24 +41,24 @@ function project_get_object ($group_id)
 
 class Group extends savane_error
 {
-  var $data_array; # Associative array of data from db.
+  var $data_array; # Data from db.
   var $type_data_array;
   var $group_id;
   var $db_result; # Database result set handle.
   var $perm_data_array; # Permissions data row from db.
-  var $is_admin; # Whether the use is an admin/super user of this project.
+  var $is_admin; # Whether the user is an admin/super user of this project.
 
-  function __construct($id)
+  function __construct ($id)
   {
-    parent::__construct();
+    parent::__construct ();
     $this->group_id = $id;
     $this->db_result =
-      db_execute ("SELECT * FROM groups WHERE group_id=?", [$id]);
-    if (db_numrows($this->db_result) < 1)
+      db_execute ("SELECT * FROM groups WHERE group_id = ?", [$id]);
+    $this->type_data_array = $this->data_array = [];
+    if (db_numrows ($this->db_result) < 1)
       {
         # Function in class we extended.
         $this->setError ('Group Not Found');
-        $this->data_array = array();
         return;
       }
    # Set up an associative array for use by other functions.
@@ -67,15 +67,14 @@ class Group extends savane_error
    $type = $this->data_array['type'];
    $this->type_id = $type;
    $this->db_type_result =
-     db_execute ( "SELECT * FROM group_type WHERE type_id=?", array($type));
-   $this->type_data_array = array();
+     db_execute ("SELECT * FROM group_type WHERE type_id = ?", [$type]);
    if (db_numrows ($this->db_type_result) >= 1)
      $this->type_data_array = db_fetch_array ($this->db_type_result);
   }
 
   # Return database result handle for direct access.
   # Generally should NOT be used - here for supporting deprecated group.php.
-  function getData()
+  function getData ()
   {
     return $this->db_result;
   }
@@ -155,17 +154,21 @@ class Group extends savane_error
      return $this->type_data_array["is_configurable_$artifact"];
   }
 
-  function getTypePermissions ($flags)
+  function get_flags ($idx)
   {
-    $idx = "${flags}_flags";
     if (isset ($this->type_data_array[$idx]))
       return $this->type_data_array[$idx];
     return null;
   }
 
+  function getTypePermissions ($flags)
+  {
+    return $this->get_flags ("${flags}_flags");
+  }
+
   function getTypeRestrictions ($flags)
   {
-    return $this->type_data_array[$flags . '_rflags'];
+    return $this->get_flags ("${flags}_rflags");
   }
 
   function getTypeMailingListHost ()
@@ -501,10 +504,10 @@ function group_getgnu ($group_id)
   return $grp->getGNU ();
 }
 
-function group_get_result($group_id=0)
+function group_get_result ($group_id = 0)
 {
-  $grp = project_get_object($group_id);
-  return $grp->getData();
+  $grp = project_get_object ($group_id);
+  return $grp->getData ();
 }
 
 function group_getid ($group_name)
@@ -601,9 +604,8 @@ function group_getrestrictions_explained ($group_id, $artifact, $event = 1)
       return _("Project Membership is required to post on this tracker.");
     case '3':
       return _("Being logged-in is required to post on this tracker.");
-    default: # Should be '6'.
-      return _("Posting on this tracker is disabled.");
     }
+  return _("Posting on this tracker is disabled.");
 }
 
 function group_gettypepermissions ($group_id, $flags)
@@ -756,7 +758,7 @@ function group_get_preference ($group_id, $preference_names)
       $val_arr[$name] = null;
     }
 
-  $arg_list = utils_str_join (", ", "?", count ($pref_arr));
+  $arg_list = utils_placeholders ($pref_arr);
   $result =
     db_execute ("
       SELECT preference_name,preference_value FROM group_preferences
