@@ -210,10 +210,6 @@ function html_feedback ($bottom)
 
   $class_hide = 'feedback';
 
-  # With MSIE  the feedback will be
-  # in relative position, so the hiding link will not make sense.
-  if (is_broken_msie () && empty ($_GET['printer']))
-    $script_hide = '';
   # Users can choose the same behavior, disallowing the fixed positionning
   # of the feedback (less convenient as the feedback gets easily hidden,
   # requires to scroll to be accessed, but seems prefered by users of
@@ -739,9 +735,9 @@ function html_select_typedir_box ($input_name, $current_value)
       print "<option value='$dir'$sel>$title</option>\n";
     }
   print "</select> [BACKEND SPECIFIC]\n";
-  print "<p><span class='smaller'>Basic directory will make the backend"
-    . "using DownloadMakeArea(), defined in Savannah::Download; <br />\n"
-    . "CVS directory will make the backend using CvsMakeArea(), defined "
+  print "<p><span class='smaller'>Basic directory will make the backend\n"
+    . "using DownloadMakeArea(), defined in Savannah::Download;<br />\n"
+    . "CVS directory will make the backend using CvsMakeArea(), defined\n"
     . "in Savannah::Cvs.\n</span><p>";
 }
 
@@ -850,7 +846,7 @@ function site_project_header ($params)
 # rather than a direct call to site_footer() or theme_footer().
 # Params array() empty.
 # Result - print HTML directly.
-function site_project_footer ($params)
+function site_project_footer ($params = [])
 {
   html_footer ($params);
 }
