@@ -57,7 +57,6 @@ $sys_themedefault = 'Emeraud';
 $sys_enable_forum_comments = 1;
 $sys_registration_captcha = 0;
 $sys_registration_text_spam_test = 1;
-$sys_securimagedir = '/usr/src/securimage';
 
 $sys_default_domain = $_SERVER['SERVER_NAME'];
 if ($_SERVER['SERVER_PORT'] != 80)
@@ -138,6 +137,7 @@ else
 # Security issues apply even during fundrasing periods.  Please don't disable
 # this, make the banner work with the headers instead.
 utils_set_csp_headers ();
+utils_update_decimal_separator ();
 
 # Debug initialization.
 if ($sys_debug_on == true)
@@ -319,7 +319,7 @@ if (!isset ($sys_group_id))
 session_set ();
 
 # HTML layout class.
-require_once ("$file_dir/Layout.class");
+require_once ("$file_dir/layout.php");
 
 $HTML = new Layout ();
 theme_select ();
@@ -516,4 +516,5 @@ $check_group = function ($group_id)
 };
 $check_group ($group_id);
 unset ($check_grp);
+$php_self = htmlentities ($_SERVER['PHP_SELF']);
 ?>
