@@ -192,13 +192,10 @@ function markup_info($level)
       $link_tail = '';
     }
 
+  $img = html_image ('misc/edit.png', ['class' => 'icon']);
   return '<span class="smaller">('
-         .utils_help($link_head.'<img
-    src="'.$GLOBALS['sys_home'].'images/'.SV_THEME
-         .'.theme/misc/edit.png"
-    border="0" class="icon" alt=""'
-         .'
-    />' . $string . $link_tail, $text, true) . ')</span>';
+    . utils_help ("$link_head$img$string$link_tail", $text)
+    . ')</span>';
 }
 
 # Convert special markup characters in the input text to real HTML.
@@ -487,7 +484,7 @@ function _full_markup($line, $allow_headings, &$context_stack, &$quoted_text)
 
   # The code below marks up recognized special characters,
   # without starting a new context (e.g. <strong> and <em>).
-  $line = _markup_inline($line);
+  $line = _markup_inline ($line);
 
   # Paragraph formatting.
 
@@ -522,13 +519,11 @@ function _full_markup($line, $allow_headings, &$context_stack, &$quoted_text)
     }
   # Don't start a new paragraph again, if we already did that.
   if (isset ($context_stack[0]) && substr ($context_stack[0], 0, 4) == '</p>')
-    {
-      $start_paragraph = false;
-    }
+    $start_paragraph = false;
   # Add proper closing tags when we encounter an empty line.
   # note that there might be no closing tags, in this case
   # the line will remain emtpy.
-  if (preg_match('/^(|\s*)$/', $line))
+  if (preg_match ('/^(|\s*)$/', $line))
     {
       $line = join("\n", $context_stack)."$line";
       # Empty the stack.
@@ -546,9 +541,7 @@ function _full_markup($line, $allow_headings, &$context_stack, &$quoted_text)
     }
   # Append a linebreak while in paragraph mode.
   if (isset ($context_stack[0]) && substr ($context_stack[0], 0, 4) == '</p>')
-    {
-      $line .= '<br />';
-    }
+    $line .= '<br />';
   return $line;
 }
 
@@ -702,8 +695,8 @@ function _markup_inline($line)
   if ($group_id)
     $comingfrom = "&amp;comingfrom=$group_id";
 
-  if (strlen($line) == 0)
-    return;
+  if (strlen ($line) == 0)
+    return "";
   # Replace references to image files with <img>.
   preg_match_all ('/\(?((files? ))#(?P<file_id>\d+)'
                   . '(?P<comment>[^),]*)((\)|, )?)/',
@@ -867,12 +860,12 @@ function _markup_inline($line)
     . '(((' . $protocols . '):)?\/\/'
     # match any character except whitespace (non-greedy) for
     # the actual link, followed by the closing brace ']'.
-    . '([^\s]+?))\]/', function ($match) use ($protocol_relative)
+    . '([^\s]+?))\]/', function ($match_arr) use ($protocol_relative)
                       {
-                        $url = $match[1];
+                        $url = $match_arr[1];
                         $string = $url;
-                        if ($match[3] == $protocol_relative)
-                          $string = $match[4];
+                        if ($match_arr[3] == $protocol_relative)
+                          $string = $match_arr[4];
                         return '<a href="' . $url . '">' . $string . '</a>';
                       }, $line);
 
@@ -945,7 +938,7 @@ function markup_ascii_line ($line, &$item_no)
 # amounts to enumerations in ordered lists, Savannah sr #110621.
 function markup_ascii ($text)
 {
-  $lines = explode ("\n", utils_unconvert_htmlspecialchars ($text));
+  $lines = explode ("\n", htmlspecialchars_decode ($text, ENT_QUOTES));
   $item_no = [];
   $ret = '';
   foreach ($lines as $line)
