@@ -72,10 +72,10 @@ $sane_sanitizers['digits'] = function ($in, &$out, $i, $arg)
 {
   if (!is_scalar ($in[$i]))
     return 1;
-  if (!preg_match("/\d+/", $in[$i], $match))
+  if (!preg_match ("/\d+/", $in[$i], $match_arr))
     return 1;
 
-  $out[$i] = $match[0];
+  $out[$i] = $match_arr[0];
 
   if ($arg === null)
     return 0;
@@ -101,9 +101,9 @@ $sane_sanitizers['xdigits'] = function ($in, &$out, $i, $arg)
 {
   if (!is_scalar ($in[$i]))
     return 1;
-  if (!preg_match("/[[:xdigit:]]+/", $in[$i], $match))
+  if (!preg_match ("/[[:xdigit:]]+/", $in[$i], $match_arr))
     return 1;
-  $out[$i] = $match[0];
+  $out[$i] = $match_arr[0];
   return 0;
 };
 
@@ -118,6 +118,7 @@ $sane_sanitizers['name'] = function ($in, &$out, $i, $arg)
   if (!is_scalar ($n))
     return 1;
 
+  $min_len = 1;
   $max_len = 34;
   $allow_dots = false;
 
@@ -126,6 +127,8 @@ $sane_sanitizers['name'] = function ($in, &$out, $i, $arg)
 
   if (is_array ($arg))
     {
+      if (isset ($arg['min_len']))
+        $min_len = $arg['min_len'];
       if (isset ($arg['max_len']))
         $max_len = $arg['max_len'];
       if (isset ($arg['allow_dots']))
@@ -138,7 +141,15 @@ $sane_sanitizers['name'] = function ($in, &$out, $i, $arg)
     $reg_exp .= '.';
   $reg_exp .= "_[:alnum:]-]*$/";
 
-  if (strlen ($n) > $max_len)
+  $len = strlen ($n);
+  if (!$min_len && !$len)
+    {
+      $out[$i] = $n;
+      return 0;
+    }
+  if ($len > $max_len)
+    return 1;
+  if ($len < $min_len)
     return 1;
 
   if (!preg_match ($reg_exp, $n))
@@ -382,9 +393,9 @@ function sane_import($method, $names)
   $values = array();
   $input =& $GLOBALS[sane_input_array_name ($method)];
 
-  foreach ($names as $fn => $name)
+  foreach ($names as $fnc => $name)
     {
-      $func = sane_prefix_func ($fn);
+      $func = sane_prefix_func ($fnc);
       if ($func !== null)
         sane_apply_func ($func, $input, $name, $values);
       else
@@ -393,60 +404,6 @@ function sane_import($method, $names)
   return $values;
 }
 
-# Backward security function. This will sanitize input already passed via
-# register globals.
-#
-# In theory, this function should "disappear" from the code and be replaced by
-# sane_XXX functions.
-#
-# This function should be used whenever user input is used:
-#        - get
-#        - post
-#        - cookies
-# This will escape the strings appropriately.
-
-# Function to obtain user input that come from undefined method.
-# This should be used only where user can legitimately send data by
-# different methods.
-# (this is why it is called sane_all, to avoid having it used everywhere)
-# This does not take uploads depending on PHP version, so use sane_upload()
-# instead, if necessary.
-function sane_all($varname)
-{
-  if (sane_isset($varname))
-    return $_REQUEST[$varname];
-  else
-    return '';
-}
-
-# Function to obtain user input submitted as url args
-# (like thispage.php?arg=userinput).
-function sane_get($varname)
-{
-  if (isset($_GET[$varname]))
-    return $_GET[$varname];
-  else
-    return '';
-}
-
-# Function to obtain user input submitted while posting a form.
-function sane_post($varname)
-{
-  if (isset($_POST[$varname]))
-    return $_POST[$varname];
-  else
-    return '';
-}
-
-# Function to obtain user input submitted in a cookie.
-function sane_cookie($varname)
-{
-  if (isset($_COOKIE[$varname]))
-    return $_COOKIE[$varname];
-  else
-    return '';
-}
-
 # Does an isset. Not really necessary, just for cohesion sake.
 function sane_isset($varname)
 {
