@@ -1,10 +1,10 @@
 <?php
-# Session functions
+# Session functions.
 #
 # Copyright (C) 1999-2000 The SourceForge Crew
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2003-2006 Derek Feichtinger <derek.feichtinger--cern.ch>
-# Copyright (C) 2017, 2018 Ineiev
+# Copyright (C) 2017, 2018, 2022 Ineiev
 #
 # This file is part of Savane.
 #
@@ -129,22 +129,7 @@ function session_login_valid($form_loginname,
         }
     }
 
-  # TODO: Brother site login mechanism should be implemented later for
-  #       all authentication methods:
-
-  # Authentication method: PAM based
-  # this requires the 'pam_auth' php extension from
-  # http://www.math.ohio-state.edu/~ccunning/pam_auth.html.
-  if($usr['user_pw'] == 'PAM')
-    {
-      $pam_error='';
-      if(! pam_auth($form_loginname, $form_pw, $pam_error))
-        {
-          fb(_('Invalid Password (AFS)'), 1);
-          return false;
-        }
-    }
-  else if ($usr['user_pw'] == '')
+  if ($usr['user_pw'] == '')
     {
       # Authentication method: Kerberos
       # If both user_pw and unix_pw are empty the user might
@@ -434,36 +419,35 @@ function session_set_new_cookies($user_id, $cookie_for_a_year=0, $stay_in_ssl=1)
 
 function session_set()
 {
-  global $G_SESSION,$G_USER;
+  global $G_SESSION, $G_USER;
 
   # Assume bad session_hash and session. If all checks work, then allow
   # otherwise make new session.
   $id_is_good = 0;
 
   # Here also check for good hash, set if new session is needed.
-  extract(sane_import('cookie',
-    ['hash' =>'session_hash', 'digits' => 'session_uid']));
+  extract (sane_import ('cookie',
+    ['hash' =>'session_hash', 'digits' => 'session_uid'])
+  );
   if ($session_hash && $session_uid)
     {
-      $result=db_execute("SELECT * FROM session WHERE session_hash=? AND user_id=?",
-                         array($session_hash, $session_uid));
-      $G_SESSION = db_fetch_array($result);
+      $result = db_execute ("
+        SELECT * FROM session WHERE session_hash = ? AND user_id = ?",
+        [$session_hash, $session_uid]
+      );
+      $G_SESSION = db_fetch_array ($result);
 
       # Does hash exist?
-      if ($G_SESSION['session_hash'])
-        {
-          $id_is_good = 1;
-        }
+      if (isset ($G_SESSION['session_hash']) && $G_SESSION['session_hash'])
+        $id_is_good = 1;
     } # if ($session_hash && $session_uid)
 
   if ($id_is_good)
-    {
-      session_setglobals($G_SESSION['user_id']);
-    }
+    session_setglobals ($G_SESSION['user_id']);
   else
     {
-      unset($G_SESSION);
-      unset($G_USER);
+      unset ($G_SESSION);
+      unset ($G_USER);
     }
 }
 
