@@ -7,7 +7,7 @@
 # Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2018, 2019, 2020, 2022 Ineiev
+# Copyright (C) 2018, 2019, 2020, 2022, 2023 Ineiev
 #
 # This file is part of Savane.
 #
@@ -119,7 +119,7 @@ function &trackers_data_get_notification_settings ($group_id, $tracker)
     SELECT fv.bug_fv_id, fv.value, fv.email_ad, fv.send_all_flag
     FROM {$tracker}_field f, {$tracker}_field_value fv
     WHERE
-      fv.group_id = ?  AND f.field_name = ?
+      fv.group_id = ? AND f.field_name = ?
       AND fv.bug_field_id = f.bug_field_id AND fv.status != 'H'",
     [$group_id, $cat_field_name]
   );
@@ -211,8 +211,8 @@ function trackers_data_show_notification_settings (
             . "email addresses (comma-separated list).")
          . "</p>\n";
 
-$cb_name = "{$tracker}_send_all_changes";
-$txt_name = "{$tracker}_new_item_address";
+  $cb_name = "{$tracker}_send_all_changes";
+  $txt_name = "{$tracker}_new_item_address";
   print "<span class='preinput'><label for=\"$txt_name\">"
     . _("Global List:") . "</label></span><br />\n&nbsp;&nbsp;"
     . "<input type='text' id=\"$txt_name\" name=\"$txt_name\""
@@ -226,8 +226,8 @@ $txt_name = "{$tracker}_new_item_address";
   print '<h2>' . _("Private items exclude list") . "</h2>\n";
   if ($show_intro_msg != 0)
     print '<p>'
-      . _("Addresses registered in this list will be excluded from default mail
-notification for private items.")
+      . _("Addresses registered in this list will be excluded from default "
+          . "mail\nnotification for private items.")
       . "</p>\n";
 
   $txt_name = "${tracker}_private_exclude_address";
@@ -283,7 +283,7 @@ function trackers_data_post_notification_settings ($group_id, $tracker)
   $res_gl = db_autoexecute (
     'groups',
     [
-      "$tracker}_glnotif" => $notif_value,
+      "{$tracker}_glnotif" => $notif_value,
       "send_all_$tracker" => $send_all_changes,
       "new_{$tracker}_address" => $new_item_address,
       $private_exclude_address_name => $private_exclude_address
@@ -457,8 +457,7 @@ function trackers_data_get_all_report_fields ($report_id = 100)
         {
           $have_bug_id = true;
           # bug_id should always show up.
-          if (!$arr['show_on_result'])
-            $arr['show_on_result'] = 1;
+          $arr['show_on_result'] = 1;
         }
       $field_id = trackers_data_get_field_id ($field);
       $BF_USAGE_BY_NAME[$field]['show_on_query'] =
@@ -526,14 +525,14 @@ function trackers_data_get_field_predefined_values (
 
   if ($active_only)
     {
-      if ($checked and !is_array ($checked))
+      if ($checked && !is_array ($checked))
         {
-          $status_cond = "AND  (status IN ('A','P') OR value_id=?) ";
+          $status_cond = "AND (status IN ('A', 'P') OR value_id = ?) ";
           $status_cond_params = [$checked];
         }
       else
         {
-          $status_cond = "AND  status IN ('A','P') ";
+          $status_cond = "AND status IN ('A', 'P') ";
           $status_cond_params = [];
         }
     }
@@ -575,24 +574,40 @@ function trackers_data_use_field_predefined_values ($field, $group_id)
   return db_numrows ($result);
 }
 
-function trackers_data_by_field_var ($by_field_id)
+function trackers_data_field_val ($field, $idx, $by_field_id = false)
 {
   $var_name = "BF_USAGE_BY_";
   if ($by_field_id)
-    return $var_name . 'ID';
-  return $var_name . 'NAME';
+    $var_name .= 'ID';
+  else
+    $var_name .= 'NAME';
+
+  if (!isset ($GLOBALS[$var_name][$field][$idx]))
+    return null;
+  return $GLOBALS[$var_name][$field][$idx];
 }
 
 function trackers_data_is_custom ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  return $GLOBALS[$var_name][$field]['custom'];
+  return trackers_data_field_val ($field, 'custom', $by_field_id);
+}
+
+function trackers_data_nonempty ($field, $idx, $by_field_id = false)
+{
+  return !empty (trackers_data_field_val ($field, $idx, $by_field_id));
 }
 
 function trackers_data_is_special ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  return !empty ($GLOBALS[$var_name][$field]['special']);
+  return trackers_data_nonempty ($field, 'special', $by_field_id);
+}
+
+function trackers_data_custom_val ($field, $idx, $by_field_id)
+{
+  $ret = trackers_data_field_val ($field, "custom_$idx", $by_field_id);
+  if ($ret !== null)
+    return $ret;
+  return trackers_data_field_val ($field, $idx, $by_field_id);
 }
 
 # 1 = not mandatory
@@ -600,49 +615,27 @@ function trackers_data_is_special ($field, $by_field_id = false)
 # 3 = mandatory whenever possible
 function trackers_data_mandatory_flag ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  if (isset ($GLOBALS[$var_name][$field]['custom_empty_ok']))
-    return $GLOBALS[$var_name][$field]['custom_empty_ok'];
-  if (isset ($GLOBALS[$var_name][$field]['empty_ok']))
-    return $GLOBALS[$var_name][$field]['empty_ok'];
-  return null;
-}
-
-function trackers_data_do_keep_history ($field, $by_field_id = false)
-{
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  if (isset ($GLOBALS[$var_name][$field]['custom_keep_history']))
-    return $GLOBALS[$var_name][$field]['custom_keep_history'];
-  if (isset ($GLOBALS[$var_name][$field]['keep_history']))
-    return $GLOBALS[$var_name][$field]['keep_history'];
-  return null;
+  return trackers_data_custom_val ($field, 'empty_ok', $by_field_id);
 }
 
 function trackers_data_is_required ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  if (isset ($GLOBALS[$var_name][$field]['required']))
-    return $GLOBALS[$var_name][$field]['required'];
-  return null;
+  return trackers_data_field_val ($field, 'required', $by_field_id);
 }
 
 function trackers_data_is_used ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  return $GLOBALS[$var_name][$field]['use_it'];
+  return trackers_data_field_val ($field, 'use_it', $by_field_id);
 }
 
 function trackers_data_is_showed_on_query ($field)
 {
-  global $BF_USAGE_BY_NAME;
-  # show_on_query can be unset if not in the DB.
-  return !empty ($BF_USAGE_BY_NAME[$field]['show_on_query']);
+  return trackers_data_nonempty ($field, 'show_on_query');
 }
 
 function trackers_data_is_showed_on_result ($field)
 {
-  global $BF_USAGE_BY_NAME;
-  return !empty ($BF_USAGE_BY_NAME[$field]['show_on_result']);
+  return trackers_data_nonempty ($field, 'show_on_result');
 }
 
 # Return a TRUE value if non project members who still are
@@ -650,9 +643,9 @@ function trackers_data_is_showed_on_result ($field)
 # (first bit of show_on_add set).
 function trackers_data_is_showed_on_add ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  if (isset ($GLOBALS[$var_name][$field]['show_on_add']))
-    return $GLOBALS[$var_name][$field]['show_on_add'] & 1;
+  $val = trackers_data_field_val ($field, 'show_on_add', $by_field_id);
+  if (!empty ($val))
+    return $val & 1;
   return 0;
 }
 
@@ -660,9 +653,9 @@ function trackers_data_is_showed_on_add ($field, $by_field_id = false)
 # access this field (second bit of show_on_add set).
 function trackers_data_is_showed_on_add_nologin ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  if (isset ($GLOBALS[$var_name][$field]['show_on_add']))
-    return $GLOBALS[$var_name][$field]['show_on_add'] & 2;
+  $val = trackers_data_field_val ($field, 'show_on_add', $by_field_id);
+  if (!empty ($val))
+    return $val & 2;
   return 0;
 }
 
@@ -670,10 +663,7 @@ function trackers_data_is_showed_on_add_nologin ($field, $by_field_id = false)
 # access this field.
 function trackers_data_is_showed_on_add_members ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  if (isset ($GLOBALS[$var_name][$field]['show_on_add_members']))
-    return $GLOBALS[$var_name][$field]['show_on_add_members'];
-  return null;
+  return trackers_data_field_val ($field, 'show_on_add_members', $by_field_id);
 }
 
 function trackers_data_is_date_field ($field, $by_field_id = false)
@@ -706,8 +696,7 @@ function trackers_data_is_username_field ($field, $by_field_id = false)
 
 function trackers_data_is_project_scope ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  return $GLOBALS[$var_name][$field]['scope'] == 'P';
+  return 'P' == trackers_data_field_val ($field, 'scope', $by_field_id);
 }
 
 function trackers_data_is_status_closed ($status)
@@ -717,49 +706,32 @@ function trackers_data_is_status_closed ($status)
 
 function trackers_data_get_field_name ($field_id)
 {
-  global $BF_USAGE_BY_ID;
-  return $BF_USAGE_BY_ID[$field_id]['field_name'];
+  return trackers_data_field_val ($field_id, 'field_name', true);
 }
 
 function trackers_data_get_field_id ($field_name)
 {
-  global $BF_USAGE_BY_NAME;
-  if (isset ($BF_USAGE_BY_NAME[$field_name]['bug_field_id']))
-    return $BF_USAGE_BY_NAME[$field_name]['bug_field_id'];
-  return null;
+  return trackers_data_field_val ($field_name, 'bug_field_id');
 }
 
 function trackers_data_get_group_id ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  return $GLOBALS[$var_name][$field]['group_id'];
+  return trackers_data_field_val ($field, 'group_id', $by_field_id);
 }
 
 function trackers_data_get_label ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  if (isset ($GLOBALS[$var_name][$field]['custom_label']))
-    return $GLOBALS[$var_name][$field]['custom_label'];
-  if (isset ($GLOBALS[$var_name][$field]['label']))
-    return $GLOBALS[$var_name][$field]['label'];
-  return null;
+  return trackers_data_custom_val ($field, 'label', $by_field_id);
 }
 
 function trackers_data_get_description ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  $desc = $GLOBALS[$var_name][$field]['custom_description'];
-  if (!isset ($desc))
-    $desc = $GLOBALS[$var_name][$field]['description'];
-  return $desc;
+  return trackers_data_custom_val ($field, 'description', $by_field_id);
 }
 
 function trackers_data_get_display_type ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  if (isset ($GLOBALS[$var_name][$field]['display_type']))
-    return $GLOBALS[$var_name][$field]['display_type'];
-  return null;
+  return trackers_data_field_val ($field, 'display_type', $by_field_id);
 }
 
 function trackers_data_get_display_type_in_clear ($field, $by_field_id = false)
@@ -777,38 +749,30 @@ function trackers_data_get_display_type_in_clear ($field, $by_field_id = false)
 
 function trackers_data_get_keep_history ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  if (isset ($BF_USAGE_BY_ID[$field]['custom_keep_history']))
-    return $GLOBALS[$var_name][$field]['custom_keep_history'];
-  return $GLOBALS[$var_name][$field]['keep_history'];
+  return trackers_data_custom_val ($field, 'keep_history', $by_field_id);
 }
 
 function trackers_data_get_place ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  return $GLOBALS[$var_name][$field]['place'];
+  return trackers_data_field_val ($field, 'place', $by_field_id);
 }
 
 function trackers_data_get_scope ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  return  $GLOBALS[$var_name][$field]['scope'];
+  return trackers_data_field_val ($field, 'scope', $by_field_id);
 }
 
 function trackers_data_get_col_width ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  return $GLOBALS[$var_name][$field]['col_width'];
+  return trackers_data_field_val ($field, 'col_width', $by_field_id);
 }
 
 function trackers_data_get_display_size ($field, $by_field_id = false)
 {
-  $var_name = trackers_data_by_field_var ($by_field_id);
-  $val = null;
-  if (isset ($GLOBALS[$var_name][$field]['custom_display_size']))
-    $val = $GLOBALS[$var_name][$field]['custom_display_size'];
-  elseif (isset ($GLOBALS[$var_name][$field]['display_size']))
-    $val = $GLOBALS[$var_name][$field]['display_size'];
+  $val = "0/0";
+  $v = trackers_data_custom_val ($field, 'display_size', $by_field_id);
+  if ($v !== null)
+    $val = $v;
   return explode ('/', $val);
 }
 
@@ -1123,7 +1087,7 @@ function trackers_data_update_usage (
         'custom_empty_ok' => $emp_ok, 'custom_keep_history' => $keep_hist,
         'transition_default_auth' => $transition_default_auth
       ],
-      DB_AUTOQUERY_UPDATE, "bug_field_id=? AND group_id=?",
+      DB_AUTOQUERY_UPDATE, "bug_field_id = ? AND group_id = ?",
       [$field_id, $group_id]
     );
   else
@@ -1149,45 +1113,25 @@ function trackers_data_update_usage (
 # Get a list of technicians for a tracker.
 function trackers_data_get_technicians ($group_id)
 {
-  # FIXME: The cleanest thing would be to issue one SQL command.
-  # But we have to handle the fact that "no setting" = get back
-  # to the group, or even group type, setting.
-
-  # In fact, this is terrible, we cannot return something else than
-  # a mysql result if we do not want to rewrite 25 functions.
-  # So we get the appropriate list of users... and finally issue
-  # a mysql command only to be able to return a mysql result.
-  # Please, propose something better at savannah-dev@gnu.org.
-
   # Get list of members.
   $members_res = db_execute ("
-    SELECT user.user_id FROM user,user_group
-    WHERE user.user_id=user_group.user_id AND user_group.group_id = ?",
+    SELECT user.user_id FROM user, user_group
+    WHERE user.user_id = user_group.user_id AND user_group.group_id = ?",
     [$group_id]
   );
-  $sql = "SELECT user_id,user_name FROM user WHERE ";
-  $params = array();
-  $notfirst = false;
+  $sql = "SELECT user_id, user_name FROM user WHERE ";
+  $uids = [];
   while ($member = db_fetch_array ($members_res))
-    {
-      $mem_ck = member_check (
-        $member['user_id'], $group_id,
-        member_create_tracker_flag (ARTIFACT) . '1'
-      );
-      if ($mem_ck)
-        {
-          if ($notfirst)
-            $sql .= " OR ";
-          $sql .= " user_id = ?";
-          $params[] = $member['user_id'];
-          $notfirst = true;
-        }
-    }
-  if (empty ($params))
-    # Return a valid (but empty) resultset.
-    $sql .= 'NULL';
+    $uids[] = $member['user_id'];
+  $uids = member_check_array (
+    $uids, $group_id, member_create_tracker_flag (ARTIFACT) . '1'
+  );
+  if (empty ($uids))
+    $sql .= 'NULL'; # Return a valid (but empty) result set.
+  else
+    $sql .= 'user_id IN (' . utils_placeholders ($uids) . ')';
   $sql .= " ORDER BY user_name";
-  return db_execute ($sql, $params);
+  return db_execute ($sql, $uids);
 }
 
 # Get transitions valid for a given tracker as an array.
@@ -1208,50 +1152,9 @@ function trackers_data_get_submitters ($group_id = false)
   );
 }
 
-# Get the items for this project.
-function trackers_data_get_items ($group_id = false, $artifact)
+function trackers_data_get_followups ($item_id, $rorder = false)
 {
-  return db_execute ("
-    SELECT bug_id, summary FROM $artifact
-    WHERE group_id = ?  AND status_id <> 3
-    ORDER BY bug_id DESC LIMIT 100",
-    [$group_id]
-  );
-}
-
-# Get the list of ids this is dependent on.
-function trackers_data_get_dependent_items (
-  $item_id = false, $artifact, $notin = false
-)
-{
-  $sql = "
-    SELECT is_dependent_on_item_id FROM " . ARTIFACT . "_dependencies
-    WHERE item_id = ? AND is_dependent_on_item_id_artifact = ?";
-  $sql_params = [$item_id, $artifact];
-  if ($notin)
-    {
-      $sql .= ' AND is_dependent_on_item_id NOT IN ('
-        . utils_str_join (',', '?', count ($dict))
-        . ')';
-      $sql_params = array_merge ($sql_params, $notin);
-    }
-  return db_execute ($sql, $sql_params);
-}
-
-function trackers_data_get_valid_bugs ($group_id = false, $item_id = '')
-{
-  return db_execute ("
-    SELECT bug_id, summary
-    FROM " . ARTIFACT . " a
-    WHERE group_id = ? AND bug_id <> ? AND a.resolution_id <> 2
-    ORDER BY bug_id DESC LIMIT 200",
-    [$group_id, $item_id]
-  );
-}
-
-function trackers_data_get_followups ($item_id = false, $rorder = false)
-{
-  if ($rorder == true)
+  if ($rorder)
     $rorder = "DESC";
   else
     $rorder = "ASC";
@@ -1262,17 +1165,15 @@ function trackers_data_get_followups ($item_id = false, $rorder = false)
     db_execute ("
       SELECT DISTINCT
         bug_history_id, field_name, old_value, spamscore, new_value, date,
-        user_name, realname, user_id, value AS comment_type
+        mod_by AS user_id, value AS comment_type
       FROM
         (
           SELECT
             b.bug_history_id, b.field_name, b.old_value, b.spamscore,
-            b.new_value, b.date, b.mod_by, b.type, t.group_id AS grp,
-            u.user_name, u.realname, u.user_id
-          FROM ${tracker}_history b, ${tracker} t, user u
+            b.new_value, b.date, b.mod_by, b.type, t.group_id AS grp
+          FROM ${tracker}_history b, $tracker t
           WHERE
-            t.bug_id = ? AND b.bug_id = t.bug_id
-            AND b.field_name = 'details' AND b.mod_by = u.user_id
+            t.bug_id = ? AND b.bug_id = t.bug_id AND b.field_name = 'details'
         ) bhi
         LEFT JOIN
         (
@@ -1297,22 +1198,19 @@ function trackers_data_get_commenters ($item_id)
   );
 }
 
-function trackers_data_get_history ($item_id = false)
+function trackers_data_get_history ($item_id)
 {
   return db_execute ("
-    SELECT
-      h.field_name, h.old_value, h.date, h.type, user.user_name, h.new_value
-     FROM " . ARTIFACT . "_history h, user
-     WHERE
-       h.mod_by = user.user_id AND h.field_name <> 'details' AND bug_id = ?
-     ORDER BY h.date DESC",
-     [$item_id]
+    SELECT field_name, old_value, date, type, mod_by, new_value
+    FROM " . ARTIFACT . "_history
+    WHERE field_name <> 'details' AND bug_id = ?  ORDER BY date DESC",
+    [$item_id]
   );
 }
 
 function trackers_data_get_attached_files ($item_id = false, $order = 'DESC')
 {
-  if ($order != 'DESC' and $order != 'ASC')
+  if ($order != 'DESC' && $order != 'ASC')
     die (
       "trackers_data_get_attached_files: invalid \$order '"
       . htmlescape ($order) . "')"
@@ -1328,13 +1226,11 @@ function trackers_data_get_attached_files ($item_id = false, $order = 'DESC')
   );
 }
 
-function trackers_data_get_cc_list ($item_id = false)
+function trackers_data_get_cc_list ($item_id)
 {
   return db_execute ("
-    SELECT bug_cc_id, cc.email, cc.added_by, cc.comment, cc.date, u.user_name
-    FROM " . ARTIFACT . "_cc cc, user u
-    WHERE added_by = u.user_id AND bug_id = ?
-    ORDER BY date DESC",
+    SELECT bug_cc_id, email, added_by, comment, date
+    FROM " . ARTIFACT . "_cc WHERE bug_id = ?  ORDER BY date DESC",
     [$item_id]
   );
 }
@@ -1500,8 +1396,8 @@ function trackers_data_append_canned_response ($details, $canned_response)
         }
       if (!empty ($details))
         $details .= $separator;
-      $details .= utils_unconvert_htmlspecialchars (
-        db_result ($res, 0, 'body')
+      $details .= htmlspecialchars_decode (
+        db_result ($res, 0, 'body'), ENT_QUOTES
       );
       $any_response_used = true;
     }
@@ -1708,10 +1604,8 @@ function trackers_data_handle_update (
         );
 
       # Add poster in CC.
-      if (!user_get_preference ("skipcc_postcomment"))
-        trackers_add_cc (
-          $item_id, $group_id, user_getid (), "-COM-", $changes
-        );
+      if (user_isloggedin () && !user_get_preference ("skipcc_postcomment"))
+        trackers_add_cc ($item_id, user_getid (), "-COM-", $changes);
     }
 
   # If we are on the cookbook, the original submission have been details.
@@ -1808,8 +1702,8 @@ function trackers_data_handle_update (
 
       # Add CC (CC in case of comment would have been already entered,
       # if there is only a comment, we should not end up here).
-      if (!user_get_preference ("skipcc_updateitem"))
-        trackers_add_cc ($item_id, $group_id, user_getid (), "-UPD-");
+      if (user_isloggedin () && !user_get_preference ("skipcc_updateitem"))
+        trackers_add_cc ($item_id, user_getid (), "-UPD-");
     }
   else
     {
@@ -2312,7 +2206,7 @@ function trackers_data_create_item ($group_id, $vfl, &$extra_addresses)
   # (currently, no option to avoid this, but we could make this a notif
   # configuration option, if wanted).
   if (user_isloggedin ())
-    trackers_add_cc ($item_id, $group_id, user_getid (), "-SUB-");
+    trackers_add_cc ($item_id, user_getid (), "-SUB-");
   return $item_id;
 }
 
@@ -2375,7 +2269,7 @@ function trackers_data_get_canned_responses ($group_id)
   );
 }
 
-function trackers_data_get_reports ($group_id, $user_id = 100, $sober = false)
+function trackers_data_get_reports ($group_id, $user_id = 100)
 {
   # Currently, reports are group based.
   # Print first system reports.
@@ -2384,10 +2278,7 @@ function trackers_data_get_reports ($group_id, $user_id = 100, $sober = false)
   # If user is unknown then get only project-wide and system wide reports
   # else get personal reports in addition  project-wide and system wide.
 
-  # We usually want non-sober specific query forms.
   $system_scope = 'S';
-  if ($sober)
-    $system_scope = 'SSB';
 
   $sql = "
     SELECT report_id,name FROM " . ARTIFACT . "_report
@@ -2585,26 +2476,23 @@ function trackers_data_count_field_value_usage (
 
 function trackers_data_quote_comment ($item_id, $quote_no)
 {
-  $entry = false;
-  if ($quote_no == 0)
-    {
-      $result = db_execute ("
-        SELECT
-          u.user_id, u.user_name, u.realname, a.date, a.details, a.spamscore
-        FROM " . ARTIFACT . " a, user u
-        WHERE a.submitted_by = u.user_id AND a.bug_id = ? LIMIT 1",
-        [$item_id]
-      );
-      $entry = db_fetch_array ($result)['details'];
-      $label = _("original submission:");
-    }
-  else
+  if ($quote_no)
     {
+      $entry = false;
       $result = trackers_data_get_followups ($item_id);
       if ($quote_no <= db_numrows ($result))
         $entry = db_result ($result, $quote_no - 1, 'old_value');
       $label = sprintf (_("comment #%s:"), $quote_no);
     }
+  else
+    {
+      $result = db_execute (
+        "SELECT details FROM " . ARTIFACT . " WHERE bug_id = ? LIMIT 1",
+        [$item_id]
+      );
+      $entry = db_fetch_array ($result)['details'];
+      $label = _("original submission:");
+    }
   if ($entry === false)
     return $entry;
   $entry = html_entity_decode (trackers_decode_value ($entry));
