@@ -27,10 +27,7 @@ function format_item_details (
   $preview = [], $allow_quote = true
 )
 {
-  # ASCII must not be translated.
   # Format the details rows from trackers_history.
-  global $sys_datefmt;
-
   $data = [];
   $i = $max_entries = $hist_id = 0;
 
@@ -39,9 +36,10 @@ function format_item_details (
   {
     $i++;
     $max_entries++;
+    $user_id = $entry['user_id'];
     $data[$i]['user_id'] = $entry['user_id'];
-    $data[$i]['user_name'] = $entry['user_name'];
-    $data[$i]['realname'] = $entry['realname'];
+    $data[$i]['user_name'] = user_getname ($user_id);
+    $data[$i]['realname'] = user_getname ($user_id, true);
     $data[$i]['date'] = $entry['date'];
     $data[$i]['comment_type'] = $entry['comment_type'];
     $data[$i]['text'] = trackers_decode_value ($entry['old_value']);
@@ -57,16 +55,14 @@ function format_item_details (
 
   # Get original submission.
   $result = db_execute ("
-    SELECT u.user_id, u.user_name, u.realname, a.date, a.details, a.spamscore
-    FROM " . ARTIFACT . " a, user u
-    WHERE a.submitted_by = u.user_id AND a.bug_id = ? AND a.group_id = ?
-    LIMIT 1",
-    [$item_id, $group_id]
+    SELECT submitted_by, date, details, spamscore
+    FROM " . ARTIFACT . " WHERE bug_id = ?  LIMIT 1", [$item_id]
   );
   $entry = db_fetch_array ($result);
-  $data[$i]['user_id'] = $entry['user_id'];
-  $data[$i]['user_name'] = $entry['user_name'];
-  $data[$i]['realname'] = $entry['realname'];
+  $user_id = $entry['submitted_by'];
+  $data[$i]['user_id'] = $user_id;
+  $data[$i]['user_name'] = user_getname ($user_id);
+  $data[$i]['realname'] = user_getname ($user_id, true);
   $data[$i]['date'] = $entry['date'];
   $data[$i]['text'] = $entry['details'];
   $data[$i]['comment_internal_id'] = '0';
@@ -91,21 +87,7 @@ function format_item_details (
   else
     krsort($data);
 
-  # No followup comment -> return now.
   $out = '';
-  if (!count ($data))
-    {
-      if ($ascii)
-        return $out;
-      return '<span class="warn">'
-        . _("No followups have been posted") . '</span>';
-    }
-
-  # Only one comment: it is the original submission, skip it in ascii mode
-  # because it will be already included elsewhere.
-  if (count ($data) < 2 && $ascii)
-    return;
-
   if ($ascii)
     $out .= "    _______________________________________________________\n\n"
       . "Follow-up Comments:\n\n";
@@ -168,7 +150,7 @@ function format_item_details (
       $score = "title=\"$score\"";
       $int_id = $entry['comment_internal_id'];
       $comment_ids = "&amp;item_id=$item_id&amp;comment_internal_id=$int_id";
-      $url_start = htmlentities ($_SERVER['PHP_SELF']) . '?func=';
+      $url_start = "{$GLOBALS['php_self']}?func=";
       $class = utils_altrow (++$j);
 
       # Find out what would be this comment number.
@@ -192,6 +174,11 @@ function format_item_details (
           'digits' => 'comment_internal_id'
         ]
       ));
+      # Full markup only for original submission.
+      if ($comment_number < 1)
+        $markedup_text = markup_full ($entry['text']);
+      else
+        $markedup_text = markup_rich ($entry['text']);
       if ($is_spam)
         {
           # If we are dealing with the original submission put a feedback
@@ -207,23 +194,23 @@ function format_item_details (
           # If we are in printer mode, simply skip if.
           if (!empty ($_REQUEST['printer']))
             continue;
+          $own_post = user_isloggedin () && user_getid () == $entry['user_id'];
 
           # The admin may actually want to see the incriminated item.
           # The submitter too.
           if (($func == "viewspam" && $comment_internal_id == $int_id)
-              || ($entry['user_id'] != 100 && user_getid() == $entry['user_id']))
+              || $own_post)
             {
-              # Should be item content, without making links, with no markup.
-              # It is only for checks purpose, nothing else.
               $out .= "\n<tr class=\"$class\">\n"
                 . "<td valign='top'>\n<span class='warn'>("
                 . _("Why is this post is considered to be spam? "
                     . "Users may have reported it to be\nspam or, if it has "
                     . "been recently posted, it may just be waiting for "
                     . "spamchecks\nto be run.")
-                . ")</span><br />\n<span class='preinput'>"
-                . _("Spam content:") . "</span><br />\n<br />"
-                . nl2br ($entry['text']) . "</td>\n<td class=\"{$class}extra\" "
+                . ")</span><br />\n";
+              if ($own_post || $is_admin)
+                $out .=  $markedup_text;
+              $out .= "<br />\n<br /></td>\n<td class=\"{$class}extra\" "
                 . "id=\"spam{$int_id}\">\n";
 
               $out .=
@@ -270,7 +257,7 @@ function format_item_details (
             $name = "{$entry['realname']} <{$entry['user_name']}>";
           else
             $name = "Anonymous";
-          $out .= sprintf ("Date: %-30sBy: %s\n", $date, $name);
+          $out .= sprintf ("Date: %-30s By: %s\n", $date, $name);
           $out .= $comment_type;
           if ($comment_type)
             $out .= "\n";
@@ -324,8 +311,6 @@ function format_item_details (
             }
         } # if ($poster_id != 100)
 
-      $text_to_markup = $entry['text'];
-
       $out .= "\n<tr class=\"$class\"><td valign='top'>\n";
       if ($entry['preview'])
         $out .= "<p><b>" . _("This is a preview") . "</b></p>\n";
@@ -347,13 +332,7 @@ function format_item_details (
         $out .=  "<button name='quote_no' value='$comment_number'>"
           . _('Quote') . "</button>";
       $out .= "<br />\n$comment_type";
-      $out .= '<div class="tracker_comment">';
-      # Full markup only for original submission.
-      if ($comment_number < 1)
-        $out .= markup_full ($text_to_markup);
-      else
-        $out .= markup_rich ($text_to_markup);
-      $out .= "</div>\n</td>\n";
+      $out .= "<div class='tracker_comment'>$markedup_text</div>\n</td>\n";
 
       $out .= "<td class=\"{$class}extra\">"
         . utils_user_link ($entry['user_name'], $entry['realname'], true);
@@ -372,8 +351,8 @@ function format_item_details (
 
       # If not a member of the project, allow to mark as spam.
       # For performance reason, do not check here if the user already
-      # flagged the comment as spam, it will be done only if he tries to
-      # do it twice.
+      # flagged the comment as spam, it will be done only if the user tries
+      # to do it twice.
       if (user_isloggedin() && !$icon
           && $poster_id != user_getid () && empty ($_REQUEST['printer']))
         {
@@ -395,9 +374,6 @@ function format_item_details (
 
 function format_item_changes ($changes, $item_id, $group_id)
 {
-  # ASCII must not be translated.
-  global $sys_datefmt;
-
   # FIXME: strange, with %25s it does not behave exactly like
   # trackers_field_label_display.
   $fmt = "%24s: %23s => %-23s\n";
@@ -488,19 +464,11 @@ function format_item_changes ($changes, $item_id, $group_id)
   return $out;
 }
 
-function format_item_attached_files ($item_id, $group_id, $ascii = false,
-                                     $sober = false)
+function format_item_attached_files ($item_id, $group_id, $ascii = false)
 {
-  # ASCII must not be translated.
-  global $sys_datefmt, $HTML, $sys_home;
+  global $HTML, $sys_home, $php_self;
   $out = '';
-  # In sober output, we assume that files are interesting in their
-  # chronological order.
-  # For instance, on the cookbook, if screenshots are provided, the author
-  # of the item is likely to have posted them in the order of their use.
-  # On the other hand, on non-sober output, what matters is the latest
-  # submitted item.
-  $order = $sober? 'ASC': 'DESC';
+  $order = 'DESC';
 
   $result = trackers_data_get_attached_files ($item_id, $order);
   $rows = db_numrows ($result);
@@ -518,7 +486,7 @@ function format_item_attached_files ($item_id, $group_id, $ascii = false,
   if ($ascii)
     $out .= "    _______________________________________________________\n"
       . "File Attachments:\n\n";
-  elseif (!$sober)
+  else
     $out .= $HTML->box_top(_("Attached Files"),'',1);
 
   # Determine what the print out format is based on output type (Ascii, HTML).
@@ -549,38 +517,26 @@ function format_item_attached_files ($item_id, $group_id, $ascii = false,
           $mem_ck = member_check (
             0, $group_id, member_create_tracker_flag (ARTIFACT) . '2'
           );
-          if ($mem_ck && !$sober)
+          if ($mem_ck)
             {
               $html_delete = '<span class="trash"><a href="'
-                . htmlentities ($_SERVER['PHP_SELF'])
-                . "?func=delete_file&amp;item_id=$item_id"
+                . "$php_self?func=delete_file&amp;item_id=$item_id"
                 . "&amp;item_file_id=$item_file_id\">"
                 . html_image_trash (['alt' => _("Delete"), 'class' => 'icon'])
                 . '</a></span>';
             }
 
-          if ($sober)
-            $out .= '<div>&nbsp;&nbsp;&nbsp;- ';
-          else
-            $out .= '<div class="' . utils_altrow($i) . '">' . $html_delete;
-
+          $out .= '<div class="' . utils_altrow($i) . '">' . $html_delete;
           $out .= "<a href=\"$href\">file #$item_file_id: &nbsp;";
 
-          if ($sober)
-              $out .= "<a href=\"$href\">"
-                . htmlspecialchars (db_result ($result, $i, 'filename'))
-                . '</a>';
-          else
-            {
-              # TRANSLATORS: the first argument is file name, the second
-              # is user's name.
-              $out .= sprintf (
-                _('<!-- file -->%1$s added by %2$s'),
-                htmlspecialchars (db_result ($result, $i, 'filename'))
-                . '</a>',
-                utils_user_link (db_result ($result, $i, 'user_name'))
-              );
-            }
+          # TRANSLATORS: the first argument is file name, the second
+          # is user's name.
+          $out .= sprintf (
+            _('<!-- file -->%1$s added by %2$s'),
+            htmlspecialchars (db_result ($result, $i, 'filename'))
+            . '</a>',
+            utils_user_link (db_result ($result, $i, 'user_name'))
+          );
 
           $out .= ' <span class="smaller">('
             . utils_filesize (0, db_result ($result, $i, 'filesize'));
@@ -597,7 +553,7 @@ function format_item_attached_files ($item_id, $group_id, $ascii = false,
         }
     } # for ($i = 0; $i < $rows; $i++)
 
-  if ($ascii || $sober)
+  if ($ascii)
     $out .= "\n";
   else
     $out .= $HTML->box_bottom (1);
@@ -608,8 +564,7 @@ function format_item_attached_files ($item_id, $group_id, $ascii = false,
 # Show the files attached to this bug.
 function format_item_cc_list ($item_id, $group_id, $ascii = false)
 {
-  # ASCII must not be translated.
-  global $sys_datefmt, $HTML;
+  global $HTML, $php_self;
   if ($ascii)
     $ascii = 1;
   else
@@ -699,7 +654,8 @@ function format_item_cc_list ($item_id, $group_id, $ascii = false)
       $u_id = user_getid ();
       $u_name = user_getname ($u_id);
       $u_mail = user_getemail ($u_id);
-      $res_name = db_result ($result, $i, 'user_name');
+      $user_name = user_getname (db_result ($result, $i, 'added_by'));
+      $res_name = $user_name;
       $mem_ck = member_check (
         0, $group_id, member_create_tracker_flag (ARTIFACT) . '2'
       );
@@ -708,14 +664,13 @@ function format_item_cc_list ($item_id, $group_id, $ascii = false)
         || $u_name == $res_name
       )
         $html_delete = '<span class="trash"><a href="'
-          . htmlentities ($_SERVER['PHP_SELF'])
-          . "?func=delete_cc&amp;item_id=$item_id"
+          . "$php_self?func=delete_cc&amp;item_id=$item_id"
           . "&amp;item_cc_id=$item_cc_id\">"
           . html_image_trash (['alt' => _("Delete"), 'class' => 'icon'])
           . '</a></span>';
 
       $out .= '<li class="' . utils_altrow ($i) . '">' . $html_delete;
-      $u_link = utils_user_link (db_result ($result, $i, 'user_name'));
+      $u_link = utils_user_link ($user_name);
       # TRANSLATORS: the first argument is email, the second is user's name.
       $out .=
         sprintf (_('<!-- email --> %1$s added by %2$s'), $email, $u_link);
