@@ -29,38 +29,6 @@ require_once ("$dir_name/../sendmail.php");
 require_once ("$dir_name/data.php");
 require_once ("$dir_name/format.php");
 
-# Return the file that should be included, according to the URL
-# requested. If the file start with ?, it's an index.
-function trackers_include ()
-{
-  # Keep the dirname only if it's admin.
-  $dir = get_module_include_dir ($_SERVER['SCRIPT_NAME'], 0, 1);
-  $pre = '';
-  if ($dir != "admin")
-    $dir = '';
-  else
-    {
-      $dir .= "/";
-      $pre = "../";
-    }
-
-  return
-   "$pre../include/trackers_run/$dir" . basename ($_SERVER['SCRIPT_NAME']);
-}
-
-# Does like trackers_include() but load an arbitrary page of the common
-# tracker code. This is useful for trackers that have non-standard behavior
-# needs to present some standard page inside a non standard location.
-function trackers_bastardinclude ($page, $is_admin_page = '0')
-{
-  $pre = '';
-  if ($is_admin_page)
-    $pre = "../";
-
-  return "$pre../include/trackers_run/$page.php";
-}
-
-
 # Generate URL arguments from a variable wether scalar or array.
 function trackers_convert_to_url_arg ($varname, $var)
 {
@@ -201,7 +169,6 @@ function trackers_field_display (
   $show_unknown = false, $tab = 25
 )
 {
-  global $sys_datefmt;
   $output = '';
 
   if ($label)
@@ -265,7 +232,7 @@ function trackers_field_display (
             $output .= utils_format_date ($value);
         else
           $output .= trackers_field_date (
-            $field_name, ($value == 0)? '': strftime ("%Y-%m-%d", $value)
+            $field_name, ($value == 0)? null: date ("Y-m-d", $value)
           );
         }
       break;
@@ -292,11 +259,12 @@ function trackers_field_display (
 }
 
 function trackers_field_date (
-  $field, $value = '', $size = 0, $maxlength = 0, $ro = false
+  $field, $value, $size = 0, $maxlength = 0, $ro = false
 )
 {
-  # Value is formatted as Y-m-d.
-  $t = explode ('-', $value);
+  if ($value !== null)
+    # Value is formatted as Y-m-d.
+    $t = explode ('-', $value);
   $year = isset ($t[0])? $t[0]: null;
   $month = isset ($t[1])? $t[1]: null;
   $day = isset ($t[2])? $t[2]: null;
@@ -331,8 +299,6 @@ function trackers_multiple_field_date (
   $ro = false
 )
 {
-  # FIXME: this is broken, should be made as trackers_field_date.
-
   if ($ro)
     {
       if ($date_begin || $date_end)
@@ -355,17 +321,20 @@ function trackers_multiple_field_date (
   return "<table><tr><td>$html</td></tr></table>\n";
 }
 
+function trackers_date_op_list ()
+{
+  return ['*', '>', '=', '<'];
+}
+
 function trackers_field_date_operator ($field_name, $value = '', $ro = false)
 {
   if ($ro)
     return htmlspecialchars ($value);
-  $sel = ' selected="selected"';
+  $options = '';
+  foreach (trackers_date_op_list () as $v)
+    $options .= form_option ($v, $value, htmlspecialchars ($v));
   return '<select title="' . _("comparison operator")
-    . "\" name=\"${field_name}_op\">"
-    . '<option value=">"' . (($value == '>')? $sel: '') . ">&gt;</option>\n"
-    . '<option value="="' . (($value == '=')? $sel: '') . ">=</option>\n"
-    . '<option value="<"' . (($value == '<')? $sel: '') . ">&lt;</option>\n"
-    . "</select>\n";
+    . "\" name=\"${field_name}_op\">$options</select>\n";
 }
 
 function trackers_field_text (
@@ -408,7 +377,7 @@ function trackers_field_textarea (
 # If box_name is given, then impose this name in the select box
 # of the  HTML form otherwise use the field_name.
 function trackers_field_box (
-  $field_name, $box_name = '', $group_id, $checked = false, $show_none = false,
+  $field_name, $box_name, $group_id, $checked = false, $show_none = false,
   $text_none = 'None', $show_any = false, $text_any = 'Any',
   $allowed_transition_only = false, $show_unknown = false
 )
@@ -502,7 +471,7 @@ function trackers_field_box (
 # If box_name is given then impose this name in the select box
 # of the  HTML form otherwise use the field_name.
 function trackers_multiple_field_box (
-  $field_name, $box_name = '', $group_id, $checked = false, $show_none = false,
+  $field_name, $box_name, $group_id, $checked = false, $show_none = false,
   $text_none = 'None', $show_any = false, $text_any = 'Any',
   $show_value = false
 )
@@ -909,7 +878,7 @@ function trackers_mail_followup (
   $artifact = 0
 )
 {
-  global $sys_datefmt, $int_probablyspam, $sys_home, $sys_default_domain;
+  global $int_probablyspam, $sys_home, $sys_default_domain;
   global $sys_mail_replyto, $sys_mail_domain;
 
   # If presumed to be a spam, no notifications.
@@ -967,7 +936,6 @@ function trackers_mail_followup (
       );
       $body .= "\n";
       # All other regular fields now.
-      $i = 0;
       while ($field_name = trackers_list_all_fields ())
         {
           # If the field is a special field or if not used by his project
@@ -981,25 +949,11 @@ function trackers_mail_followup (
             $field_name, $group_id, db_result ($result, 0, $field_name),
             false, true, true, true
           );
-          $i++;
           $body .= "\n";
         }
-      $body .= "\n";
-
-      # Now display other special fields.
-      $body .=
-        "    _______________________________________________________\n\n"
-        . "Details:\n"
-        . trackers_field_display (
-            'details', $group_id, db_result ($result, 0, 'details'),
-            true, true, true, true
-          );
-
-      # Then output the history of bug details from newest to oldest.
-      $body .= "\n\n" . format_item_details ($item_id, $group_id, true);
-
-      # Then output the history of bug details from newest to oldest.
-      $body .= "\n\n" . format_item_attached_files ($item_id, $group_id, true);
+      if (ARTIFACT === $artifact)
+        $body .= "\n\n" . format_item_details ($item_id, $group_id, true)
+          . "\n\n" . format_item_attached_files ($item_id, $group_id, true);
     }
 
   # Finally output the message trailer.
@@ -1014,8 +968,8 @@ function trackers_mail_followup (
   );
   $to = join(',', $arr_addresses);
   $from = user_getrealname (0, 1) . " <$sys_mail_replyto@$sys_mail_domain>";
-  $subject = utils_unconvert_htmlspecialchars (
-    db_result ($result, 0, 'summary')
+  $subject = htmlspecialchars_decode (
+    db_result ($result, 0, 'summary'), ENT_QUOTES
   );
 
   if ($more_addresses)
@@ -1072,7 +1026,7 @@ function trackers_attach_several_files ($item_id, $group_id, &$changes)
         continue;
 
       $file_id = trackers_attach_file (
-        $item_id, $group_id, $file['tmp_name'], $file['name'], $file['type'],
+        $item_id, $file['tmp_name'], $file['name'], $file['type'],
         $file['size'], $file_description, $changes
       );
       if (!$file_id)
@@ -1095,7 +1049,7 @@ function trackers_attach_several_files ($item_id, $group_id, &$changes)
 }
 
 function trackers_attach_file (
-  $item_id, $group_id, $input_file, $input_file_name, $input_file_type,
+  $item_id, $input_file, $input_file_name, $input_file_type,
   $input_file_size, $file_description, &$changes
 )
 {
@@ -1231,7 +1185,7 @@ function trackers_attach_file (
   );
   # Add the guy in CC.
   if (user_isloggedin () && !user_get_preference ("skipcc_updateitem"))
-    trackers_add_cc ($item_id, $group_id, user_getid (), "-UPD-");
+    trackers_add_cc ($item_id, user_getid (), "-UPD-");
   return $file_id;
 }
 
@@ -1264,7 +1218,7 @@ function trackers_insert_cc ($item_id, $cc, $added_by, $comment, $date)
   return $res;
 }
 
-function trackers_add_cc ($item_id, $group_id, $email, $comment)
+function trackers_add_cc ($item_id, $email, $comment)
 {
   $user_id = (user_isloggedin ()? user_getid (): 100);
 
@@ -1445,8 +1399,8 @@ function trackers_add_sort_criteria ($criteria_list, $order, $msort)
       $i = 0;
       foreach ($arr as $attr)
         {
-          preg_match ( "/\s*([^<>]*)([<>]*)/", $attr, $match);
-          list(, $mattr, $mdir) = $match;
+          preg_match ("/\s*([^<>]*)([<>]*)/", $attr, $match_arr);
+          list (, $mattr, $mdir) = $match_arr;
           if ($mattr == $order)
             {
               if (($mdir == '>') || (!isset ($mdir)))
