@@ -47,7 +47,7 @@ if ($func == "digest")
           . "of this page."
         )
       . "</p>\n";
-    exit (0);
+    goto end_of_file;
   }
 if ($func == "digestselectfield")
   {
@@ -64,27 +64,21 @@ if ($func == "digestselectfield")
           );
         $items_for_digest = [];
         while ($deps = db_fetch_array ($res_deps))
-          {
-            $items_for_digest[] = $deps['is_dependent_on_item_id'];
-          }
+          $items_for_digest[] = $deps['is_dependent_on_item_id'];
       }
 
     if (!is_array ($items_for_digest))
-      {
-        exit_error (_("No items selected for digest"));
-      }
+      exit_error (_("No items selected for digest"));
 
     trackers_header (['title' => _("Digest Items: Fields Selection")]);
-    print '<form action="' . htmlentities ($_SERVER['PHP_SELF'])
-      . "\" method='get'>\n"
-      . "<input type='hidden' name='group' value=\"$group\" />\n"
-      . "<input type='hidden' name='func' value='digestget' />\n";
+    print form_tag (['method' => 'get'])
+      . form_hidden (['group' => $group, 'func' => 'digestget']);
 
     # Keep track of the selected items.
     $count = 0;
     foreach ($items_for_digest as $item)
       {
-        print form_input("hidden", "items_for_digest[]", $item);
+        print form_input ("hidden", "items_for_digest[]", $item);
         $count++;
       }
 
@@ -102,7 +96,7 @@ if ($func == "digestselectfield")
 
     $i = 0;
     # Select fields.
-    while ($field_name = trackers_list_all_fields())
+    while ($field_name = trackers_list_all_fields ())
       {
         if (!trackers_data_is_used ($field_name))
           continue;
@@ -114,7 +108,7 @@ if ($func == "digestselectfield")
         # Item ID is mandatory.
         if ($field_name == "bug_id")
             {
-              print form_input ("hidden", "field_used[$field_name]", "1")
+              print form_hidden (["field_used[$field_name]" => "1"])
                 . "\n";
               continue;
             }
@@ -129,24 +123,24 @@ if ($func == "digestselectfield")
       }
     # Comments is not an authentic field but could be useful. We allow
     # addition of the latest comment.
-    print '<div class="' . utils_altrow($i) . '">'
+    print '<div class="' . utils_altrow ($i) . '">'
       . form_checkbox ("field_used[latestcomment]", 1) . '&nbsp;&nbsp;'
       . _("Latest Comment") . ' <span class="smaller"><em>- '
       . _("Latest comment posted about the item.") . "</em></span></div>\n";
 
-    print form_footer(_("Submit"));
-    trackers_footer(array());
-    exit (0);
+    print form_footer (_("Submit"));
+    trackers_footer ([]);
+    goto end_of_file;
   } # if ($func == "digestselectfield")
 
 if ($func != "digestget")
-  exit (0);
+  goto end_of_file;
 
-if (!is_array($items_for_digest))
-  exit_error(_("No items selected for digest"));
+if (!is_array ($items_for_digest))
+  exit_error (_("No items selected for digest"));
 
-if (!is_array($field_used))
-  exit_error(_("No fields selected for digest"));
+if (!is_array ($field_used))
+  exit_error (_("No fields selected for digest"));
 
 trackers_header (
   ['title' => _("Digest") . ' - ' . utils_format_date (time ())]
@@ -159,96 +153,102 @@ foreach ($items_for_digest as $item)
     $i++;
     $result =
       db_execute (
-        "SELECT * FROM " . ARTIFACT . " WHERE bug_id=? AND group_id=?",
-        array($item, $group_id)
+        "SELECT * FROM " . ARTIFACT . " WHERE bug_id = ? AND group_id = ?",
+        [$item, $group_id]
       );
 
+    $res_arr = db_fetch_array ($result);
     # Skip it is it is private but the user got no privilege.
     # Normally, the user should not even been able to select this item.
     # But someone nasty could forge the arguments of the script... So its
     # better to check everytime.
-    if (db_result ($result, 0, 'privacy') == "2"
-        && !member_check_private (0, db_result ($result, 0, 'group_id')))
+    if ($res_arr['privacy'] == "2"
+        && !member_check_private (0, $res_arr['group_id']))
       continue;
 
     # Show summary if requested.
     $summary = '';
-    if (isset($field_used['summary']) && $field_used['summary'] == 1)
-      $summary = db_result ($result, 0, 'summary');
+    if (isset ($field_used['summary']) && $field_used['summary'] == 1)
+      $summary = $res_arr['summary'];
 
     # Show if the item is closed with an icon.
-    $icon = '<img border="0" src="' . $GLOBALS['sys_home'] . 'images/'
-       . SV_THEME . '.theme/bool/';
-    if (db_result ($result, 0, 'status_id') != 1)
-      $icon .= 'ok.png" alt="' .  _("Closed Item") . '" />';
+    if ($res_arr['status_id'] != 1)
+      {
+        $img_file = 'ok.png'; $img_alt = _("Closed Item");
+      }
     else
-      $icon .= 'wrong.png" alt="' . _("Open Item") . '" />';
+      {
+        $img_file = 'wrong.png'; $img_alt = _("Open Item");
+      }
+    $icon = html_image ("bool/$img_file", ['alt' => $img_alt]);
 
     print '<div class="' . utils_altrow ($i) . '">';
     print '<span class="large"><span class="'
-     . utils_get_priority_color (
-         db_result ($result, 0, 'priority'),
-         db_result ($result, 0, 'status_id')
-       )
+     . utils_get_priority_color ($res_arr['priority'], $res_arr['status_id'])
      . "\">$icon&nbsp; "
      . utils_link ("?func=detailitem&amp;item_id=$item", ARTIFACT . " #$item")
      . ": &nbsp;$summary &nbsp;</span></span><br /><br />\n";
 
     $field_count = 0;
-    while ($field_name = trackers_list_all_fields())
+    $halves = ['', ''];
+    while ($field_name = trackers_list_all_fields ())
       {
         # Some field can be ignored in any cases.
-        if ($field_name == "status_id"
-            || $field_name == "summary"
-            || $field_name == "bug_id"
-            || $field_name == "details"
-            || $field_name == "comment_type_id" )
+        if (in_array ($field_name,
+              ["status_id", "summary", "bug_id", "details", "comment_type_id"])
+        )
           continue;
 
         # Check the fields.
-        if (!isset($field_used[$field_name]) || $field_used[$field_name] != 1)
+        if (!isset ($field_used[$field_name]) || $field_used[$field_name] != 1)
           continue;
 
+        if ($field_name == 'updated')
+          {
+            $res_arr['updated'] = $res_arr['date'];
+            $result = db_execute ("
+              SELECT date FROM " . ARTIFACT . "_history WHERE bug_id = ?
+              ORDER BY date DESC LIMIT 1", [$item]
+            );
+            if (db_numrows ($result) >= 1)
+              $res_arr['updated'] = db_result ($result, 0, 'date');
+          }
+
         $field_count++;
         if ($field_count == 2)
           $field_count = 0;
 
-        $side = $field_count? "right": "left";
-        print '<span class="' . "split$side" .'">';
-
         $value =
           trackers_field_display (
-            $field_name, db_result ($result, 0, 'group_id'),
-            db_result ($result, 0, $field_name), false, false, true
+            $field_name, $res_arr['group_id'], $res_arr[$field_name],
+            false, false, true
           );
         # If it is an user name field, show full user info.
-        if ($field_name == "assigned_to"
-            || $field_name == "submitted_by")
-          $value = utils_user_link ($value,
-                                     user_getrealname (user_getid ($value)));
-        print
+        if ($field_name == "assigned_to" || $field_name == "submitted_by")
+          $value = utils_user_link (
+            $value, user_getrealname (user_getid ($value))
+          );
+        $halves[$field_count] .=
           trackers_field_label_display (
-            $field_name, db_result ($result, 0, 'group_id'), false, false
+            $field_name, $res_arr['group_id'], false, false
           )
-         . " $value";
-        print '</span>';
-        if ($field_count == 1)
-          print "<br />\n";
+         . " $value<br />\n";
       }
+    print "<div class='splitright'>{$halves[1]}</div>\n";
+    print "<div class='splitleft'>{$halves[0]}</div>\n";
 
     # Finally include details + last comment, if asked.
     if (isset ($field_used['details']) && $field_used["details"] == 1)
       print '<hr class="clearr" /><div class="smaller">'
-        . trackers_field_display(
-            "details", db_result ($result, 0, 'group_id'),
-             db_result ($result, 0, "details"),
-             false, true, true
+        . trackers_field_display (
+            "details", $res_arr['group_id'], $res_arr["details"],
+            false, true, true
           )
         . "</div>\n";
     if (isset ($field_used["latestcomment"])
         && $field_used["latestcomment"] == 1)
       {
-        $detail_result =
+        $result =
           db_execute ("
             SELECT old_value, mod_by, realname, user_name
             FROM " . ARTIFACT . "_history, user
@@ -258,15 +258,15 @@ foreach ($items_for_digest as $item)
             [$item]
           );
         $last_comment = null;
-        if (db_numrows ($detail_result) > 0)
+        if (db_numrows ($result) > 0)
           {
-            $last_comment = db_result($detail_result, 0, 'old_value');
-            $mod_by = db_result($detail_result, 0, 'mod_by');
+            $res_arr = db_fetch_array ($result);
+            $last_comment = $res_arr['old_value'];
+            $mod_by = $res_arr['mod_by'];
             if ($mod_by != 100)
               {
-                $realname = db_result ($detail_result, 0, 'realname');
-                $user_name =
-                  '&lt;' . db_result ($detail_result, 0, 'user_name') . '&gt;';
+                $realname = $res_arr['realname'];
+                $user_name = '&lt;' . $res_arr['user_name'] . '&gt;';
               }
             else
               {
@@ -275,13 +275,18 @@ foreach ($items_for_digest as $item)
               }
           }
         if ($last_comment)
-          print '<hr class="clearr" /><div class="smaller">'
-            . '<span class="preinput">'
-            . sprintf(_("Latest comment posted (by %s):"),
-                      "$realname $user_name")
-            . '</span> ' . markup_rich ($last_comment) . "</div>\n";
+          {
+            print '<hr class="clearr" /><div class="smaller">'
+              . '<span class="preinput">';
+            printf (
+              _("Latest comment posted (by %s):"), "$realname $user_name"
+            );
+            print '</span> ' . markup_rich ($last_comment) . "</div>\n";
+          }
       }
     print "<p class='clearr'>&nbsp;</p>\n</div>\n\n";
   } # foreach ($items_for_digest as $item)
-trackers_footer(array());
+trackers_footer ([]);
+
+end_of_file:
 ?>
