@@ -2,7 +2,7 @@
 # Handle votes.
 #
 # Copyright (C) 2005-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2020 Ineiev
+# Copyright (C) 2017, 2020, 2022, 2023 Ineiev
 #
 # This file is part of Savane.
 #
@@ -18,13 +18,14 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-require_once('../include/init.php');
-require_directory("trackers");
-register_globals_off();
+require_once ('../include/init.php');
+require_once ('../include/html.php');
+require_directory ("trackers");
+register_globals_off ();
 
 extract (sane_import ('post',
   [
-    'true' => 'submit', 
+    'true' => 'submit',
     'array' => [['new_votes', ['digits', 'digits']]],
   ]
 ));
@@ -36,23 +37,19 @@ $remaining_votes = trackers_votes_user_remains_count(user_getid());
 if ($submit)
   {
     $result = db_execute ("
-       SELECT vote_id,tracker,item_id
-       FROM user_votes
-       WHERE user_id = ?
-       ORDER BY howmuch DESC, item_id ASC LIMIT 100",
-       array(user_getid())
+       SELECT vote_id, tracker, item_id FROM user_votes
+       WHERE user_id = ?  ORDER BY howmuch DESC, item_id ASC LIMIT 100",
+       [user_getid ()]
     );
     unset($count);
     # Build a list of votes to update: we must proceed in two step because
     # we must check that the vote count does not exceed the limit (100).
-    $new_votes_list = array();
-    $new_votes_list_item_id = array();
-    $new_votes_list_tracker = array();
+    $new_votes_list = $new_votes_list_item_id = $new_votes_list_tracker = [];
 
     $count = 0;
-    while ($row = db_fetch_array($result))
+    while ($row = db_fetch_array ($result))
       {
-        if(!isset($new_votes[$row['vote_id']]))
+        if(!isset ($new_votes[$row['vote_id']]))
           continue;
         $new_vote = $new_votes[$row['vote_id']];
         $count = $count + $new_vote;
@@ -62,22 +59,15 @@ if ($submit)
       }
 
     if ($count > 100)
-      {
-        fb(_("Vote count exceed limits, your changes have been discarded"), 1);
-      }
+      fb (_("Vote count exceed limits, your changes have been discarded"), 1);
     else
-      {
-        foreach ($new_votes_list as $vote_id => $new_vote)
-          {
-            trackers_votes_update ($new_votes_list_item_id[$vote_id],
-                                   0,
-                                   $new_vote,
-                                   $new_votes_list_tracker[$vote_id]);
-          }
-      }
-    $remaining_votes = trackers_votes_user_remains_count(user_getid());
+      foreach ($new_votes_list as $vote_id => $new_vote)
+        trackers_votes_update ($new_votes_list_item_id[$vote_id],
+          $new_vote, $new_votes_list_tracker[$vote_id]
+        );
+    $remaining_votes = trackers_votes_user_remains_count (user_getid ());
   }
-site_user_header(array('context'=>'votes'));
+site_user_header (['context' => 'votes']);
 # Simple listing. No need of anything really fancy, there will be no more
 # than hundred entries.
 
@@ -95,32 +85,33 @@ print "</p>\n";
 if ($remaining_votes < 100)
   {
     print '<p>'
-._("To change your votes, type in new numbers (using zero removes the entry
-from your votes list).") . "</p>\n";
+      . _("To change your votes, type in new numbers (using zero removes "
+          . "the entry\nfrom your votes list).")
+      . "</p>\n";
 
-    print '<form action="' . htmlentities ($_SERVER["PHP_SELF"])
-     . "\" method=\"post\">\n";
+    print form_tag ();
 
     $result = db_execute ("
       SELECT * FROM user_votes WHERE user_id = ?
       ORDER BY howmuch DESC, item_id ASC LIMIT 100",
-      array (user_getid ())
+      [user_getid ()]
     );
 
     while ($row = db_fetch_array ($result))
       {
-        if (!ctype_alnum($row['tracker']))
-          util_die(sprintf(_("Invalid tracker name: %s"),
-                           "<em>{$row['tracker']}</em>"));
+        $tr = $row['tracker'];
+        $msg = sprintf (_("Invalid tracker name: %s"), "<em>$tr/em>");
+        if (!ctype_alnum ($tr))
+          util_die ($msg);
         $res_item = db_execute ("
-          SELECT summary,vote,status_id,priority,group_id
-          FROM {$row['tracker']} WHERE bug_id=? LIMIT 1",
-          array($row['item_id'])
+          SELECT summary, vote, status_id, priority, group_id
+          FROM $tr WHERE bug_id = ? LIMIT 1",
+          [$row['item_id']]
         );
 
-        $prefix = utils_get_tracker_prefix($row['tracker']);
-        $icon = utils_get_tracker_icon($row['tracker']);
-        $vote = db_result($res_item, 0, 'vote');
+        $prefix = utils_get_tracker_prefix ($tr);
+        $icon = utils_get_tracker_icon ($tr);
+        $vote = db_result ($res_item, 0, 'vote');
         $color = utils_get_priority_color (
           db_result ($res_item, 0, 'priority'),
           db_result ($res_item, 0, 'status_id')
@@ -131,16 +122,16 @@ from your votes list).") . "</p>\n";
           . "\" name=\"new_votes[{$row['vote_id']}]\" "
           . 'size="3" maxlength="3" value="' . "{$row['howmuch']}\" />\n/ "
           . ($row['howmuch'] + $remaining_votes) . '&nbsp;&nbsp;&nbsp;&nbsp;'
-          . "<a href=\"{$GLOBALS['sys_home']}{$row['tracker']}"
+          . "<a href=\"{$GLOBALS['sys_home']}$tr"
           . "/?func=detailitem&amp;item_id={$row['item_id']}\">\n"
-          . "<img src=\"{$GLOBALS['sys_home']}images/" . SV_THEME
-          . ".theme/contexts/$icon.png\" class=\"icon\" alt=\""
-          . "{$row['tracker']}\"\n/>"
+          . html_image ("contexts/$icon.png",
+              ['class' => "icon", 'alt' => $tr]
+            )
           . db_result ($res_item, 0, 'summary') . ', '
           . sprintf (ngettext ("%s vote", "%s votes", $vote), $vote)
           . "&nbsp;<span class=\"xsmall\">($prefix #{$row['item_id']}, "
           . group_getname (db_result ($res_item, 0, 'group_id'))
-          . ')</span></a></div>'."\n";
+          . ")</span></a></div>\n";
       }
 
     print "<br />\n<div align=\"center\" class=\"noprint\">"
@@ -148,5 +139,5 @@ from your votes list).") . "</p>\n";
       . _("Submit Changes") . "\" /></div>\n</form>\n";
     print "\n\n" . show_priority_colors_key();
   }
-$HTML->footer(array());
+$HTML->footer ([]);
 ?>
