@@ -3,7 +3,7 @@
 #
 # Copyright (C) 1999-2000 The SourceForge Crew
 # Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2019 Ineiev
+# Copyright (C) 2017, 2019, 2022 Ineiev
 #
 # This file is part of Savane.
 #
@@ -24,32 +24,37 @@ require_once('../include/init.php');
 require_once('../include/people/general.php');
 register_globals_off();
 
-extract(sane_import('get', array('user_id')));
+extract (sane_import ('get', ['digits' => 'user_id']));
 
-if ((!isset ($user_id)) || $user_id == null)
+if (empty ($user_id))
   exit_missing_param();
 
-$result=db_execute("SELECT * FROM user WHERE user_id=?", array($user_id));
+$result = db_execute ("SELECT * FROM user WHERE user_id = ?", array($user_id));
 
 if (!$result || (db_numrows($result) < 1))
-  exit_error(_("User not found"));
-elseif (db_result($result,0,'people_view_skills') != 1)
-  exit_error(_("This user deactivated his/her Resume & Skills page"));
-elseif ((db_result($result,0,'status') == 'D'
-         || db_result($result,0,'status') == 'S')
-        && !user_is_super_user())
-  exit_error(_("This account was deleted."));
-# TRANSLATORS: the argument is user's name.
-site_header(array('title'=>sprintf(_("%s Resume & Skills"),
-                                   db_result($result, 0, 'realname')),
-                  'context'=>'people'));
+  exit_error (_("User not found"));
+
+if (db_result ($result, 0, 'people_view_skills') != 1)
+  exit_error (_("This user deactivated his/her Resume & Skills page"));
+
+$user_status = db_result ($result, 0, 'status');
+
+if (($user_status == 'D' || $user_status == 'S') && !user_is_super_user())
+  exit_error (_("This account was deleted."));
 
 # TRANSLATORS: the argument is user's name.
-print '<p>'.sprintf(_("Follows Resume & Skills of %s."),
-                    utils_user_link(db_result($result, 0, 'user_name'),
-                                    db_result($result, 0, 'realname'))).'</p>
-';
-utils_get_content("people/viewprofile");
+$title = sprintf (_("%s Resume & Skills"), db_result ($result, 0, 'realname'));
+site_header (['title' => $title, 'context' => 'people']);
+
+$link = utils_user_link (
+  db_result ($result, 0, 'user_name'), db_result($result, 0, 'realname')
+);
+print "<p>";
+# TRANSLATORS: the argument is user's name.
+printf (_("Follows Resume & Skills of %s."), $link);
+print "</p>\n";
+
+utils_get_content ("people/viewprofile");
 
 $resume = db_result ($result, 0, 'people_resume');
 if ($resume != '')
@@ -57,8 +62,8 @@ if ($resume != '')
     print '<h2>' . _("Resume") . "</h2>\n";
     print markup_full (htmlspecialchars ($resume));
   }
-print '<h2>' . _("Skills") ."</h2>\n";
+print '<h2>' . _("Skills") . "</h2>\n";
 print people_show_skill_inventory ($user_id);
 
-site_footer(array());
+site_footer (array());
 ?>
