@@ -1,8 +1,8 @@
 <?php
-# Offer project members keyring for download
+# Offer user's keys for download.
 #
 # Copyright (C) 2002-2005 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017 Ineiev
+# Copyright (C) 2017, 2022 Ineiev
 #
 # This file is part of Savane.
 #
@@ -21,28 +21,30 @@
 
 require_once('../include/init.php');
 register_globals_off();
-extract(sane_import('get', array('user_id')));
+extract (sane_import ('get', ['digits' => 'user_id']));
 
-# Check whether the user exists
-if (!(isset ($user_id) && $user_id))
-  exit_error(_("User not found."));
-$result = db_execute("SELECT user_name,gpg_key FROM user WHERE user_id=?",
-                     array($user_id));
-
-if (!$result || db_numrows($result) < 1)
+if (empty ($user_id))
   exit_error(_("User not found."));
 
-# Check whether a gpg key was registered
-if (!db_result($result,0,'gpg_key'))
-  exit_error(_("This user hasn't registered a GPG key."));
+$result = db_execute ("SELECT user_name, gpg_key FROM user WHERE user_id = ?",
+                      array($user_id));
 
-# If we get here, a key exists. Simply print it.
-header('Content-Type: application/pgp-keys');
-header('Content-Disposition: attachment; filename='
-       .db_result($result, 0, 'user_name').'-key.gpg');
-# TRANSLATORS: the argument is user's name.
-header('Content-Description: '
-       .sprintf(_('GPG Key of the user %s'),
-       db_result($result, 0, 'user_name')));
-print db_result($result,0,'gpg_key');
+if (!$result || db_numrows ($result) < 1)
+  exit_error(_("User not found."));
+
+$user_name = db_result ($result, 0, 'user_name');
+$gpg_key = db_result ($result, 0, 'gpg_key');
+
+if (!$gpg_key)
+  exit_error( _("This user hasn't registered a GPG key."));
+
+header ('Content-Type: application/pgp-keys');
+header ("Content-Disposition: attachment; filename=$user_name-key.gpg");
+$description =
+  sprintf (
+    # TRANSLATORS: the argument is user's name.
+    _('GPG Key of the user %s'), $user_name
+  );
+header("Content-Description: $description");
+print $gpg_key;
 ?>
