@@ -2,7 +2,7 @@
 # Copy configuration (for group admins).
 #
 # Copyright (C) 2004 Mathieu Roy <yeupou--at--gnu.org>
-# Copyright (C) 2017, 2018 Ineiev
+# Copyright (C) 2017, 2018, 2022 Ineiev
 #
 # This file is part of Savane.
 #
@@ -19,37 +19,46 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
 require_once('../../include/init.php');
 require_directory("trackers");
 
-extract(sane_import('post', array('update', 'from_group_id', 'artifact')));
+extract (sane_import ('post',
+  [
+    'true' => 'update',
+    'digits' => 'from_group_id',
+    'artifact' => 'artifact',
+  ]
+));
 
 if (!$group_id)
-  exit_no_group();
+  exit_no_group ();
 
-if (!user_ismember($group_id,'A'))
-  exit_permission_denied();
+if (!user_ismember ($group_id, 'A'))
+  exit_permission_denied ();
 
-# Initialize global bug structures.
 if ($update && $from_group_id != 100)
-  trackers_conf_copy($group_id, $artifact, $from_group_id);
+  trackers_conf_copy ($group_id, $artifact, $from_group_id);
 
-site_project_header(array('context'=>'ahome','group'=>$group_id,
-                          'title'=>_("Copy Configuration")));
+site_project_header (
+  [
+    'context' => 'ahome', 'group' => $group_id,
+    'title' => _("Copy Configuration"),
+  ]
+);
 
-print '<h2>'._("Support Trackers Configuration Copy").'</h2>
-';
-conf_form($group_id, "support");
-print '<h2>'._("Bug Trackers Configuration Copy").'</h2>
-';
-conf_form($group_id, "bugs");
-print '<h2>'._("Task Trackers Configuration Copy").'</h2>
-';
-conf_form($group_id, "task");
-print '<h2>'._("Patch Trackers Configuration Copy").'</h2>
-';
-conf_form($group_id, "patch");
+$print_h2 = function ($x)
+{
+  print '<h2>' . $x . "</h2>\n";
+};
 
-site_project_footer(array());
+$print_h2 (_("Support Tracker Configuration Copy"));
+conf_form ($group_id, "support");
+$print_h2 (_("Bug Tracker Configuration Copy"));
+conf_form ($group_id, "bugs");
+$print_h2 (_("Task Tracker Configuration Copy"));
+conf_form ($group_id, "task");
+$print_h2 (_("Patch Tracker Configuration Copy"));
+conf_form ($group_id, "patch");
+
+site_project_footer ([]);
 ?>
