@@ -139,6 +139,35 @@ function test_sys_upload_dir ()
     print 'OK';
 }
 
+function test_captcha ()
+{
+  global $sys_captchadir;
+  $default_dir = '/usr/share/php';
+
+  print "<h2>Captcha</h2>\n\n";
+  if (empty ($sys_captchadir))
+    {
+      print "<p><strong>sys_captchadir isn't set.</strong></p>\n";
+      print "<p>Falling back to default, $default_dir</p>\n";
+      $sys_captchadir = $default_dir;
+    }
+  else
+    print "<p><b>sys_captchadir</b> is set to $sys_captchadir</p>\n";
+  if (!is_dir ($sys_captchadir))
+    {
+      print "<p><strong>No $sys_captchadir directory found.</strong></p>\n";
+      return;
+    }
+  $f = "$sys_captchadir/Text/CAPTCHA.php";
+  if (!is_file ($f))
+    {
+      print "<p><strong>No $f file found.</strong></p>\n";
+      return;
+    }
+  print "<p>Sample image:</p>\n"
+    . "<p><img id='captcha' src='/captcha.php' alt='CAPTCHA' /></p>";
+}
+
 print "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
 print "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\"
     \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n\n";
@@ -158,7 +187,7 @@ if (empty($inside_siteadmin))
 installation is properly configured. It shouldn't display any sensitive
 information, since it could give details about your setup to anybody.</p>\n";
 
-print "\n<h2>Base PHP configuration</h2>\n\n";
+print "\n<h2>Basic PHP configuration</h2>\n\n";
 
 print "<p>PHP version: " . phpversion() . "</p>\n";
 
@@ -235,17 +264,18 @@ if ($unset)
 
 print "\n<h2>PHP functions</h2>\n\n";
 
-$phpfunctions = array (
-        'mysqli_connect' =>
-          'You must install/configure php-mysqli ! [REQUIRED]',
-        'gettext' => 'You should install/configure php with gettext support '
-                         . '! [RECOMMENDED]',
-        'ctype_digit' => 'You must have a PHP version supporting ctype '
-                         . '(--enable-ctype) ! [REQUIRED]',
-        'pam_auth' => 'You must have a PHP version supporting pam_auth '
-                      . 'only if you set up authentification via '
-                      . 'PAM (kerberos, AFS, etc)');
-
+$phpfunctions =
+  [
+    'mysqli_connect' =>
+      'You must install/configure php-mysqli ! [REQUIRED]',
+    'gettext' => 'You should install/configure php with gettext support '
+      . '! [RECOMMENDED]',
+    'strftime' => 'When this function is dropped from PHP '
+      . '(deprecated in 8.1), date output is expected to slow down '
+      . '! [RECOMMENDED]',
+    'ctype_digit' => 'You must have a PHP version supporting ctype '
+      . '(--enable-ctype) ! [REQUIRED]'
+ ];
 print "<p>";
 foreach ($phpfunctions as $func => $comment)
   {
@@ -336,14 +366,16 @@ else
       $GLOBALS['sys_debug_on'] = false;
 
     print "</table>\n";
-    print "<p>Savane uses safe defaults values when variables are not set
-in the configuration file.</p>\n";
+    print "<p>Savane uses safe defaults values when variables are not set "
+      . "in the configuration file.</p>\n";
     print "<p><img src='/file?file_id=test.png' alt='Test image'/></p>\n";
+    test_captcha ();
 
     print "\n<h2>MySQL configuration</h2>\n\n";
     require_once ("include/utils.php");
     require_once ("include/database.php");
-    utils_set_csp_headers ();
+    if (empty ($inside_siteadmin))
+      utils_set_csp_headers ();
     if (!db_connect ())
       print "<blockquote>Can't connect to database.</blockquote>\n";
     else
