@@ -1175,29 +1175,20 @@ $reference = 'include/trackers_run/browse.php';
       print_reference ();
       print 'intval(null) != 0' . "\n";
     }
-  $co_field = 'status_op';
-  $names = ['strings' => [[$co_field, ['>', '=', '<']]]];
+  $field = 'status';
+  $co_field = $field . '_op';
+  $names = ['strings' => [[$co_field, ['>', '=', '<', '*']]]];
   $in = [$co_field => '='];
   $out = $in;
   test_sane_import ($in, $names, $out);
-  $co_field = 'category_end';
-  $names = ['preg' => [[$co_field, '/^\d{4}-\d{1,2}-\d{1,2}$/']]];
-  $in = [$co_field => '1983-09-27'];
+  $field = 'category';
+  $co_field = $field . '_end';
+  $names = ['preg' => [[$field, $co_field, '/^\d{4}-\d{1,2}-\d{1,2}$/']]];
+  $in = [$co_field => '1983-09-27', $field => '9999-99-99'];
   $out = $in;
   test_sane_import ($in, $names, $out);
 }
 
-$reference = 'include/trackers_run/detail-sober.php';
-{
-  $names = ['digits' => 'comingfrom'];
-  $in = ['digits' => '123'];
-  $out = ['comingfrom' => null];
-  test_sane_import ($in, $names, $out);
-  $in['comingfrom'] = 'x119y';
-  $out['comingfrom'] = '119';
-  test_sane_import ($in, $names, $out);
-}
-
 $reference = 'include/trackers_run/digest.php';
 {
   $names = [
@@ -1436,7 +1427,7 @@ $reference = 'mail/admin/index.php';
           'list_name',
           [
             $key_func,
-            ['name', ['max_len' => 80, 'allow_dots' => true]]
+            ['name', ['min_len' => 0, 'max_len' => 80, 'allow_dots' => true]]
           ]
         ],
         ['description', [$key_func, 'specialchars']],
@@ -1448,8 +1439,9 @@ $reference = 'mail/admin/index.php';
     'post_changes' => true,
     'list_name' =>
       [
-        'new' => 'list.test',
+        'new' => '',
         '123' => 'tes9-t.list',
+        '456' => 'list.test'
       ],
     'description' =>
       [
@@ -2058,6 +2050,16 @@ $reference = 'project/admin/userperms.php';
   test_sane_import ($in, $names, $out);
 }
 
+$reference = 'project/memberlist.php';
+{
+  $names = ['digits' => 'detailed'];
+  $out = $in = ['detailed' => 0];
+  test_sane_import ($in, $names, $out);
+  $names = ['digits' => 'form_grp'];
+  $out = $in = ['form_grp' => 12345];
+  test_sane_import ($in, $names, $out);
+}
+
 $reference = 'project/memberlist-gpgkeys.php';
 {
   $names = ['true' => 'download'];
@@ -2309,4 +2311,10 @@ $reference = 'stats/index.php';
     $in[$n] = $out[$n] = 83521;
   test_sane_import ($in, $names, $out);
 }
+$reference = 'userguide/index.php';
+{
+  $names = ['preg' => [['file', '/^[[:alnum:]_-]+[.]html$/']]];
+  $in = $out = ['file' => 'ch01.html'];
+  test_sane_import ($in, $names, $out);
+}
 ?>
