@@ -3,7 +3,8 @@
 # Copyright (C) 2002, 2003 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2005 Sylvain Beucler
 # Copyright (C) 2015, 2016, 2017 Karl Berry
-# Copyright (C) 2013, 2017 Ineiev <ineiev@gnu.org>
+# Copyright (C) 2013, 2017, 2023 Ineiev <ineiev@gnu.org>
+# Copyright (C) 2022 Bob Proulx
 #
 # This file is part of Savane.
 #
@@ -21,10 +22,10 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 print '<meta name="Author" content="'
-.'Copyright 2018 Free Software Foundation, Inc.
-'._('Verbatim copying and distribution of this entire article
-is permitted in any medium, provided this notice is preserved.').'" />
-<meta name="Description" content="'
-._('Savannah is a central point for development, distribution
-and maintenance of free software, both GNU and non-GNU.').'" />';
+ . "Copyright 2023 Free Software Foundation, Inc.\n"
+ . _("Verbatim copying and distribution of this entire article\n"
+     . "is permitted in any medium, provided this notice is preserved.")
+ . "\" />\n<meta name=\"description\" content=\""
+ . _("Savannah is a central point for development, distribution\n"
+     . "and maintenance of free software, both GNU and non-GNU.") . "\" />\n";
 ?>
